local assets=
{
	Asset("ANIM", "anim/amulets.zip"),
	Asset("ANIM", "anim/torso_amulets.zip"),
	Asset("ATLAS", "images/inventoryimages/disguiseamulet.xml"),
	Asset("IMAGE", "images/inventoryimages/disguiseamulet.tex"),

}

--[[ Each amulet has a seperate onequip and onunequip function so we can also
add and remove event listeners, or start/stop update functions here. ]]


---DISGUISE
local function onequip(inst, owner) 
    owner.AnimState:OverrideSymbol("swap_body", "torso_amulets", "purpleamulet")

    if inst.components.fueled then
        inst.components.fueled:StartConsuming()        
    end

    if owner.components.leader then
        owner.components.leader:RemoveFollowersByTag("spider")
    end

    --Webber:
    if owner:HasTag("monster") and owner:HasTag("spiderwhisperer")and not owner:HasTag("disguised") then
        --print("this is webber")
        owner:AddTag("disguisedspider")
        owner:AddTag("disguised")
        owner:RemoveTag("monster")
        owner:RemoveTag("spiderwhisperer")
    end

    --Other monsters:
    if owner:HasTag("monster") and not owner:HasTag("spiderwhisperer") and not owner:HasTag("disguised") then
        --print("this is a generic monster")
        owner:AddTag("disguisedmonster")
        owner:AddTag("disguised")
        owner:RemoveTag("monster")
    end

    --Neutral characters:
    if IS_REVERSIBLE and not owner:HasTag("monster") and not owner:HasTag("disguised") then
        --print("this is a neutral")
        owner:AddTag("disguisedneutral")
        owner:AddTag("disguised")
        owner:AddTag("monster")
    end


end

local function onunequip(inst, owner) 
    owner.AnimState:ClearOverrideSymbol("swap_body")
    if inst.components.fueled then
        inst.components.fueled:StopConsuming()        
    end

    if owner:HasTag("disguisedspider") or owner:HasTag("disguisedmonster") and owner.components.leader then
        owner.components.leader:RemoveFollowersByTag("pig")
    end

    --webber:
    if owner:HasTag("disguisedspider") then
        --print("spider: removing disguise")
        owner:AddTag("monster")
        owner:AddTag("spiderwhisperer")
        owner:RemoveTag("disguisedspider")
        owner:RemoveTag("disguised")
    end

    --other monsters:
    if owner:HasTag("disguisedmonster") then
        --print("monster: removing disguise")
        owner:AddTag("monster")
        owner:RemoveTag("disguisedmonster")
        owner:RemoveTag("disguised")
    end

    if (IS_REVERSIBLE == true) and owner:HasTag("disguisedneutral") then
        --print("neutral: removing disguise")
        owner:RemoveTag("monster")
        owner:RemoveTag("disguisedneutral")
        owner:RemoveTag("disguised")
    end



end

---COMMON FUNCTIONS

local function onfinished(inst)
    inst:Remove()
end

local function unimplementeditem(inst)
    local player = GetPlayer()
    player.components.talker:Say(GetString(player.prefab, "ANNOUNCE_UNIMPLEMENTED"))
    if player.components.health.currenthealth > 1 then
        player.components.health:DoDelta(-player.components.health.currenthealth * 0.5)
    end

    if inst.components.useableitem then
        inst.components.useableitem:StopUsingItem()
    end
end

local function commonfn()
	local inst = CreateEntity()
    
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
    MakeInventoryPhysics(inst)   

    inst.AnimState:SetBank("amulets")
    inst.AnimState:SetBuild("amulets")
    
    inst:AddComponent("inspectable")
	
    inst:AddComponent("equippable")
    inst.components.equippable.equipslot = EQUIPSLOTS.BODY
    
    
	inst:AddComponent("dapperness")
	inst.components.dapperness.dapperness = TUNING.DAPPERNESS_SMALL    
    
    
    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.imagename = "disguiseamulet"
    inst.components.inventoryitem.atlasname = "images/inventoryimages/disguiseamulet.xml"


    inst.components.inventoryitem.foleysound = "dontstarve/movement/foley/jewlery"
    
    return inst
end


local function disguise(inst)
    local inst = commonfn(inst)


        inst:AddComponent("fueled")
        inst.components.fueled.accepting = true
        inst.components.fueled.fueltype = "NIGHTMARE"
        inst.components.fueled:InitializeFuelLevel(TUNING.YELLOWAMULET_FUEL)

        inst.components.fueled:SetDepletedFn(onfinished)

        inst.AnimState:PlayAnimation("purpleamulet")
        inst.components.equippable:SetOnEquip( onequip)
        inst.components.equippable:SetOnUnequip( onunequip )

        inst.components.dapperness.dapperness = -TUNING.DAPPERNESS_MED    

    return inst
end

STRINGS.NAMES.DISGUISEAMULET								= "Disguise Amulet"
STRINGS.RECIPE_DESC.DISGUISEAMULET							= "A trinket for hiding."

STRINGS.CHARACTERS.GENERIC.DESCRIBE.DISGUISEAMULET =
"Monsters might like this."

if IsDLCEnabled(REIGN_OF_GIANTS) then
	STRINGS.CHARACTERS.WEBBER.DESCRIBE.DISGUISEAMULET =
"If we feel like hiding..."
end	


return Prefab("common/inventory/disguiseamulet", disguise, assets)
